@@ -5,22 +5,25 @@ Created on Wed Oct 28 17:00:53 2020
 @author: win
 """
 
-import re
-import openpyxl
-import os
-from .get_full_text import Filter_text
-from .pre_processor import Pre_processor
-from .sentence_positioner import Sentence_Positioner
-from .T_pre_processor import T_pre_processor
-from .Phrase_parse import Phrase_parse
-from .Relation_extraciton import Relation_extraciton
-from .output_modified_triple import Table_extraction,Get_targetinfo
 import copy
-from .dictionary import Dictionary
-from .log_wp import Log_wp
+import os
+import re
+
 import nltk
+import openpyxl
+
+from Phrase_parse import Phrase_parse
+from Relation_extraciton_dp import Relation_extraciton
+from T_pre_processor import T_pre_processor
+from dictionary import Dictionary
+from get_full_text import Filter_text
+from log_wp import Log_wp
+from output_modified_triple import Table_extraction
+from pre_processor import Pre_processor
+from sentence_positioner import Sentence_Positioner
+
+property_list = ['solvus', 'density', 'liquidus', 'solidus']
 
-property_list = ['solvus','density','liquidus','solidus']
 
 class Acquire_all_target_info():
     def __init__(self, C_path, origin_text_path, prop_list, excels_path, out_path):
@@ -32,8 +35,8 @@ class Acquire_all_target_info():
         self.out_path = out_path
         self.log_wp = Log_wp()
 
-    def mkdir(self,file_name):
-        pathd=os.getcwd()+'\\'+file_name
+    def mkdir(self, file_name):
+        pathd = os.getcwd() + '\\' + file_name
         if os.path.exists(pathd):
             for root, dirs, files in os.walk(pathd, topdown=False):
                 for name in files:
@@ -43,12 +46,12 @@ class Acquire_all_target_info():
             os.rmdir(pathd)
         os.mkdir(pathd)
 
-    def get_doi_fromtxt(self,txt_path):
-        text_name = txt_path.replace(".txt","")
-        doi = text_name.replace("-","/",1)
+    def get_doi_fromtxt(self, txt_path):
+        text_name = txt_path.replace(".txt", "")
+        doi = text_name.replace("-", "/", 1)
         return doi
 
-    def get_abrre(self,text,prop_name):
+    def get_abrre(self, text, prop_name):
         processor = T_pre_processor(text, prop_name, self.C_path)
         text = processor.processor()
         sentences = nltk.sent_tokenize(text)
@@ -59,14 +62,14 @@ class Acquire_all_target_info():
         for sent in sentences:
             processor = T_pre_processor(sent, prop_name, self.C_path)
             filter_data = processor.processor()
-            words =  nltk.word_tokenize(filter_data)
+            words = nltk.word_tokenize(filter_data)
             for word in words:
                 abbre_exist = None
                 for type_i in range(0, len_type):
                     outcome = re.findall(alloy_write_type[type_i], word)
                     outcome_alloy = None
                     if outcome:
-                        abbre = "("+word+")"
+                        abbre = "(" + word + ")"
                         if abbre in sentences_split:
                             index_alloy = sentences_split.index(abbre) - 1
                             alloy = sentences_split[index_alloy]
@@ -80,35 +83,36 @@ class Acquire_all_target_info():
                         break
         return abbre_to_alloy
 
-    def get_text_triple(self,prop_name):
+    def get_text_triple(self, prop_name):
         self.mkdir('output_tt')
         text_path = r"output_tt\full_text"
         self.mkdir(text_path)
-        FT = Filter_text(self.origin_text_path,text_path)
+        FT = Filter_text(self.origin_text_path, text_path)
         txt_name = FT.process()
         length = len(os.listdir(self.origin_text_path))
         all_txt_info = []
-        for i in range(0,length):
+        for i in range(0, length):
             n_path = os.listdir(self.origin_text_path)[i]
             doi = self.get_doi_fromtxt(n_path)
-            file = open(text_path + '/' + n_path,'r',encoding='utf-8')
+            file = open(text_path + '/' + n_path, 'r', encoding='utf-8')
             data = file.read()
-            pre_processor = Pre_processor(data,self.C_path)
+            pre_processor = Pre_processor(data, self.C_path)
             filter_txt = pre_processor.pre_processor()
-            file_origin = open(self.origin_text_path + '/' + n_path,'r',encoding='utf-8')
+            file_origin = open(self.origin_text_path + '/' + n_path, 'r', encoding='utf-8')
             data_origin = file_origin.read()
-            abbre_pairs = self.get_abrre(data_origin,prop_name)
-            positioner = Sentence_Positioner(filter_txt,prop_name,self.C_path)
+            abbre_pairs = self.get_abrre(data_origin, prop_name)
+            positioner = Sentence_Positioner(filter_txt, prop_name, self.C_path)
             target_sents = positioner.target_sent()
-            for index,sent in target_sents.items():
-                processor = T_pre_processor(sent,prop_name,self.C_path)
+            for index, sent in target_sents.items():
+                processor = T_pre_processor(sent, prop_name, self.C_path)
                 filter_data = processor.processor()
-                parse = Phrase_parse(filter_data,prop_name,self.C_path)
-                sub_order,sub_id,object_list = parse.alloy_sub_search()
-                RE = Relation_extraciton(prop_name,filter_data,sub_order,sub_id,object_list,self.C_path,abbre_pairs)
+                parse = Phrase_parse(filter_data, prop_name, self.C_path)
+                sub_order, sub_id, object_list = parse.alloy_sub_search()
+                RE = Relation_extraciton(prop_name, filter_data, sub_order, sub_id, object_list, self.C_path,
+                                         abbre_pairs)
                 all_outcome = RE.triple_extraction()
                 if all_outcome:
-                    for id_m,info in all_outcome.items():
+                    for id_m, info in all_outcome.items():
                         sole_info = {}
                         sole_info['doi'] = doi
                         sole_info['material'] = info[0]
@@ -117,9 +121,9 @@ class Acquire_all_target_info():
                         all_txt_info.append(sole_info)
         return all_txt_info
 
-    def gather_tableinfo_textinfo(self,all_txt_info,table_info,prop_name,prop_pattern,unit_pattern_text):
+    def gather_tableinfo_textinfo(self, all_txt_info, table_info, prop_name, prop_pattern, unit_pattern_text):
         gather_outcome = []
-        for file_name,t_info in table_info.items():
+        for file_name, t_info in table_info.items():
             sole_info = {}
             all_triple_info = []
             sole_doi = []
@@ -136,10 +140,10 @@ class Acquire_all_target_info():
                     sole_m_info.pop('doi')
                 if 'material' in sole_m_info.keys():
                     sole_material = sole_m_info['material']
-                    noisy = re.findall('\s*\[.+\]',str(sole_material))
+                    noisy = re.findall('\s*\[.+\]', str(sole_material))
                     if noisy:
                         for puc in noisy:
-                            sole_material = str(sole_material).replace(puc,'')
+                            sole_material = str(sole_material).replace(puc, '')
                     triple_info['material'] = sole_material
                     sole_m_info.pop('material')
                 if 'unit' in sole_m_info.keys():
@@ -159,16 +163,16 @@ class Acquire_all_target_info():
                     triple_info['table_topic'] = sole_tag_info
                     sole_m_info.pop('table_topic')
                 if len(sole_m_info) == 1:
-                    for prop_name_t,value in sole_m_info.items():
+                    for prop_name_t, value in sole_m_info.items():
                         sole_propname = str(prop_name_t)
                         triple_info['prop_name'] = sole_propname
                         sole_value = str(value)
                         triple_info['value'] = sole_value
                 elif len(sole_m_info) >= 1:
                     get_prop = None
-                    for prop_name_t,value in sole_m_info.items():
+                    for prop_name_t, value in sole_m_info.items():
                         for pattern in prop_pattern[prop_name]:
-                            prop_search = re.findall(pattern,str(prop_name_t))
+                            prop_search = re.findall(pattern, str(prop_name_t))
                             if prop_search:
                                 sole_propname = str(prop_name_t)
                                 triple_info['prop_name'] = sole_propname
@@ -187,8 +191,8 @@ class Acquire_all_target_info():
             k = tuple(q.keys())[0]
             i = q[k]
             for n in i:
-                for w,v in n.items():
-                    if w =='value':
+                for w, v in n.items():
+                    if w == 'value':
                         gather += 1
         self.log_wp.print_log("gather number :%s", gather)
         copy_all_txt_info = copy.copy(all_txt_info)
@@ -205,10 +209,10 @@ class Acquire_all_target_info():
                     plus_info['prop_name'] = triple_info_sole['prop_name']
                     prop_value = triple_info_sole['prop_value']
                     plus_info['material'] = triple_info_sole['material']
-                    unit_search = re.findall(unit_pattern_text[prop_name],str(prop_value))
+                    unit_search = re.findall(unit_pattern_text[prop_name], str(prop_value))
                     if unit_search:
                         plus_info['unit'] = unit_search[0]
-                        prop_value = prop_value.replace(unit_search[0],'')
+                        prop_value = prop_value.replace(unit_search[0], '')
                         plus_info['value'] = prop_value
                     else:
                         plus_info['unit'] = ""
@@ -225,10 +229,10 @@ class Acquire_all_target_info():
                     plus_info['prop_name'] = triple_info_sole['prop_name']
                     prop_value = triple_info_sole['prop_value']
                     plus_info['material'] = triple_info_sole['material']
-                    unit_search = re.findall(unit_pattern_text[prop_name],str(prop_value))
+                    unit_search = re.findall(unit_pattern_text[prop_name], str(prop_value))
                     if unit_search:
                         plus_info['unit'] = unit_search[0]
-                        prop_value = prop_value.replace(unit_search[0],'')
+                        prop_value = prop_value.replace(unit_search[0], '')
                         plus_info['value'] = prop_value
                     else:
                         plus_info['unit'] = ""
@@ -241,10 +245,10 @@ class Acquire_all_target_info():
             self.log_wp.print_log("all_text number :%s", all_text)
         return gather_outcome
 
-    def transform_comp_outcome(self,all_composition):
+    def transform_comp_outcome(self, all_composition):
         ele_list = self.dict_info.ele_list
         gather_outcome = []
-        for file_name,t_info in all_composition.items():
+        for file_name, t_info in all_composition.items():
             sole_info = {}
             all_triple_info = []
             for sole_m_info in t_info:
@@ -254,10 +258,10 @@ class Acquire_all_target_info():
                 sole_m_info.pop('doi')
                 if 'material' in sole_m_info.keys():
                     sole_material = sole_m_info['material']
-                    noisy = re.findall('\[.+\]',str(sole_material))
+                    noisy = re.findall('\[.+\]', str(sole_material))
                     if noisy:
                         for puc in noisy:
-                            sole_material = str(sole_material).replace(puc,'')
+                            sole_material = str(sole_material).replace(puc, '')
                     triple_info['material'] = sole_material
                     sole_m_info.pop('material')
                 for element in ele_list:
@@ -271,7 +275,7 @@ class Acquire_all_target_info():
             gather_outcome.append(sole_info)
         return gather_outcome
 
-    def allinfo_dependencyparse(self,comp_info,prop_info):
+    def allinfo_dependencyparse(self, comp_info, prop_info):
         all_ele_doi = []
         all_prop_doi = []
         outcome = []
@@ -302,7 +306,7 @@ class Acquire_all_target_info():
                                 ele_allname.append(ele_m_name)
                         modified_ele_allname = []
                         for name in ele_allname:
-                            space_search = re.findall('\s',str(name))
+                            space_search = re.findall('\s', str(name))
                             if space_search:
                                 name_list = str(name).split()
                                 modified_ele_allname.append(str(name))
@@ -317,9 +321,9 @@ class Acquire_all_target_info():
                                 if prop_m_name not in modified_ele_allname and len(ele_doi_fullinfo) == 1:
                                     if one_material_prop['source'] == 'table':
                                         combine_info = {}
-                                        for prop_name,prop_value in one_material_prop.items():
+                                        for prop_name, prop_value in one_material_prop.items():
                                             combine_info[prop_name] = prop_value
-                                        for ele_name,ele_value in ele_doi_fullinfo[0].items():
+                                        for ele_name, ele_value in ele_doi_fullinfo[0].items():
                                             combine_info[ele_name] = ele_value
                                         all_doi_info.append(combine_info)
                                     else:
@@ -328,33 +332,33 @@ class Acquire_all_target_info():
                                     all_doi_info.append(one_material_prop)
                                 if prop_m_name in modified_ele_allname:
                                     for one_material_ele in ele_doi_fullinfo:
-                                       if 'material' in one_material_ele.keys():
-                                           ele_m_name = one_material_ele['material']
-                                           space_search = re.findall('\s',str(ele_m_name))
-                                           if space_search:
-                                               ele_m_name_split = ele_m_name.split()
-                                               if prop_m_name in ele_m_name_split or prop_m_name == ele_m_name:
-                                                   pop_name.append(ele_m_name)
-                                                   combine_info = {}
-                                                   for prop_name,prop_value in one_material_prop.items():
-                                                       combine_info[prop_name] = prop_value
-                                                   for ele_name,ele_value in one_material_ele.items():
-                                                       combine_info[ele_name] = ele_value
-                                                   all_doi_info.append(combine_info)
-                                           else:
-                                               if prop_m_name == ele_m_name :
-                                                   combine_info = {}
-                                                   for prop_name,prop_value in one_material_prop.items():
-                                                       combine_info[prop_name] = prop_value
-                                                   for ele_name,ele_value in one_material_ele.items():
-                                                       combine_info[ele_name] = ele_value
-                                                   all_doi_info.append(combine_info)
+                                        if 'material' in one_material_ele.keys():
+                                            ele_m_name = one_material_ele['material']
+                                            space_search = re.findall('\s', str(ele_m_name))
+                                            if space_search:
+                                                ele_m_name_split = ele_m_name.split()
+                                                if prop_m_name in ele_m_name_split or prop_m_name == ele_m_name:
+                                                    pop_name.append(ele_m_name)
+                                                    combine_info = {}
+                                                    for prop_name, prop_value in one_material_prop.items():
+                                                        combine_info[prop_name] = prop_value
+                                                    for ele_name, ele_value in one_material_ele.items():
+                                                        combine_info[ele_name] = ele_value
+                                                    all_doi_info.append(combine_info)
+                                            else:
+                                                if prop_m_name == ele_m_name:
+                                                    combine_info = {}
+                                                    for prop_name, prop_value in one_material_prop.items():
+                                                        combine_info[prop_name] = prop_value
+                                                    for ele_name, ele_value in one_material_ele.items():
+                                                        combine_info[ele_name] = ele_value
+                                                    all_doi_info.append(combine_info)
                         for one_material_ele in ele_doi_fullinfo:
                             if 'material' in one_material_ele.keys():
                                 ele_m_name = one_material_ele['material']
                                 if ele_m_name not in pop_name:
                                     if ele_m_name not in prop_allname:
-                                         all_doi_info.append(one_material_ele)
+                                        all_doi_info.append(one_material_ele)
                     if all_doi_info:
                         plus_info[ele_doi] = all_doi_info
                         outcome.append(plus_info)
@@ -364,57 +368,57 @@ class Acquire_all_target_info():
             outcome.append(extra_prop)
         return outcome
 
-    def structureinfo_toexcel(self,all_structureinfo,out_path):
+    def structureinfo_toexcel(self, all_structureinfo, out_path):
         ele_list = self.dict_info.ele_list
         xls = openpyxl.Workbook()
         sht = xls.create_sheet(0)
         sht = xls.create_sheet(index=0)
-        sht.cell(1,1,"Source")
-        sht.cell(1,2,"DOIs")
-        sht.cell(1,3,"table_topic")
-        sht.cell(1,4,"Material")
-        sht.cell(1,5,"Property_name")
-        sht.cell(1,6,"Property_value")
-        sht.cell(1,7,"Unit")
+        sht.cell(1, 1, "Source")
+        sht.cell(1, 2, "DOIs")
+        sht.cell(1, 3, "table_topic")
+        sht.cell(1, 4, "material")
+        sht.cell(1, 5, "Property_name")
+        sht.cell(1, 6, "Property_value")
+        sht.cell(1, 7, "Unit")
         col_n = 8
         row_now = 2
-        sht.cell(1,col_n,str("other_element_info"))
+        sht.cell(1, col_n, str("other_element_info"))
         col_n += 1
-        sht.cell(1,col_n,str("other_property_info"))
+        sht.cell(1, col_n, str("other_property_info"))
         col_n += 1
-        sht.cell(1,col_n,str("child_tag"))
+        sht.cell(1, col_n, str("child_tag"))
         col_n += 1
         for ele in ele_list:
-            sht.cell(1,col_n,ele)
+            sht.cell(1, col_n, ele)
             col_n += 1
         for m_info in all_structureinfo:
             doi = tuple(m_info.keys())[0]
             length_m_info = m_info[doi]
             for index_m in range(len(length_m_info)):
-                sht.cell(row_now,2,doi)
+                sht.cell(row_now, 2, doi)
                 material_now = length_m_info[index_m]
                 if 'source' in material_now.keys():
-                    sht.cell(row_now,1,str(material_now['source']))
+                    sht.cell(row_now, 1, str(material_now['source']))
                 if 'table_topic' in material_now.keys():
-                    sht.cell(row_now,3,str(material_now['table_topic']))
-                if 'Material' in material_now.keys():
-                    sht.cell(row_now,4,str(material_now['Material']))
+                    sht.cell(row_now, 3, str(material_now['table_topic']))
+                if 'material' in material_now.keys():
+                    sht.cell(row_now, 4, str(material_now['material']))
                 if 'prop_name' in material_now.keys():
-                    sht.cell(row_now,5,str(material_now['prop_name']))
+                    sht.cell(row_now, 5, str(material_now['prop_name']))
                 if 'value' in material_now.keys():
-                    sht.cell(row_now,6,str(material_now['value']))
+                    sht.cell(row_now, 6, str(material_now['value']))
                 if 'unit' in material_now.keys():
-                    sht.cell(row_now,7,str(material_now['unit']))
+                    sht.cell(row_now, 7, str(material_now['unit']))
                 if "other_eleinfo" in material_now.keys():
-                    sht.cell(row_now,8,str(material_now['other_eleinfo']))
+                    sht.cell(row_now, 8, str(material_now['other_eleinfo']))
                 if "other_prop_info" in material_now.keys():
-                    sht.cell(row_now,9,str(material_now['other_prop_info']))
+                    sht.cell(row_now, 9, str(material_now['other_prop_info']))
                 if "child_tag" in material_now.keys():
-                    sht.cell(row_now,10,str(material_now["child_tag"]))
+                    sht.cell(row_now, 10, str(material_now["child_tag"]))
                 col_ele = 11
                 for ele in ele_list:
                     if ele in material_now.keys():
-                        sht.cell(row_now,col_ele,material_now[ele])
+                        sht.cell(row_now, col_ele, material_now[ele])
                     col_ele += 1
                 row_now += 1
         del xls['Sheet']
@@ -429,7 +433,7 @@ class Acquire_all_target_info():
             self.mkdir('output_tt')
             text_path = r"output_tt\full_text"
             self.mkdir(text_path)
-            all_txt_info = self.get_text_triple( prop_name)
+            all_txt_info = self.get_text_triple(prop_name)
             target_property = prop_name  # 'density' 'liquidus'  'solidus'  'solvus'
             te = Table_extraction(self.excels_path, self.C_path, prop_name=target_property)
             info_all = te.property_info_extraction()
@@ -438,7 +442,7 @@ class Acquire_all_target_info():
                 i_l += len(v)
             all_composition = te.composition_triple_extraction()
             gather_outcome = self.gather_tableinfo_textinfo(all_txt_info, info_all, prop_name, prop_pattern,
-                                                       unit_pattern_text)
+                                                            unit_pattern_text)
             gather = 0
             for q in gather_outcome:
                 k = tuple(q.keys())[0]
@@ -446,7 +450,7 @@ class Acquire_all_target_info():
                 gather += len(i)
             ele_transform = self.transform_comp_outcome(all_composition)
             all_structureinfo = self.allinfo_dependencyparse(ele_transform,
-                                                        gather_outcome)
+                                                             gather_outcome)
             b = 0
             for a in all_structureinfo:
                 k = tuple(a.keys())[0]
@@ -455,6 +459,5 @@ class Acquire_all_target_info():
                     for w, v in n.items():
                         if w == 'value':
                             b += 1
-            out_path = self.out_path +'/' + str(prop_name) + '.xlsx'
-            self.structureinfo_toexcel(all_structureinfo,out_path)
-
+            out_path = self.out_path + '/' + str(prop_name) + '.xlsx'
+            self.structureinfo_toexcel(all_structureinfo, out_path)
